@@ -7,7 +7,7 @@ use File::Path qw(mkpath);
 use File::Spec;
 use File::Spec::Unix;
 use Carp qw(croak carp cluck confess);
-use Exporter qw(import);
+use Exporter;
 use LWP::UserAgent;
 use HTML::TreeBuilder::XPath;
 use Scalar::Util qw(blessed);
@@ -18,7 +18,13 @@ use HTTP::Response::Encoding;
 use HTML::HeadParser;
 use HTTP::Headers::Util;
 
-use version; our $VERSION = qv('0.2');
+use version; our $VERSION = qv('0.3');
+
+ 
+# We don't want to inherit Exporter, we can't always import the import
+# method, so this is a workaround.
+sub import { goto &Exporter::import }
+
 
 
 our @EXPORT_OK = qw(download);
